==> mitosheet2-0.1.38.tar.gz: package/lib/components/taskpanes/Import/ImportTaskpane.js <==
// Copyright (c) Mito
import React, { useEffect, useState } from 'react';
import DefaultTaskpane from '../DefaultTaskpane/DefaultTaskpane';
import FileBrowser from './FileBrowser';
import TextButton from '../../elements/TextButton';
import XLSXImport from './XLSXImport';
// CSS
import '../../../../css/taskpanes/Import/ImportTaskpane.css';
import DefaultTaskpaneHeader from '../DefaultTaskpane/DefaultTaskpaneHeader';
import DefaultTaskpaneBody from '../DefaultTaskpane/DefaultTaskpaneBody';
import { getElementsToDisplay, getFileEnding, getImportButtonStatus } from './importUtils';
function ImportTaskpane(props) {
    const [importState, setImportState] = useState({
        pathContents: {
            path_parts: props.currPathParts,
            elements: []
        },
        sort: 'last_modified_descending',
        searchString: '',
        selectedElementIndex: -1,
        loadingImport: false
    });
    // If the file being imported is an XLSX, we need additional configuration
    // and so we use an import wizard for help
    const [fileForImportWizard, setFileForImportWizard] = useState(undefined);
    // We make sure to get the elements that are displayed and use the index on that to get the correct element
    const selectedElement = getElementsToDisplay(importState)[importState.selectedElementIndex];
    /*
        Any time the current path changes, we update
        the files that are displayed
    */
    useEffect(() => {
        // When the current path changes, we reload the path contents
        void loadPathContents(props.currPathParts);
        // We also unselect anything that might be selected
        setImportState(prevImportState => {
            return Object.assign(Object.assign({}, prevImportState), { selectedElementIndex: -1 });
        });
        // Log how long the path is
        void props.mitoAPI.log('curr_path_changed', { 'path_parts_length': props.currPathParts.length });
    }, [props.currPathParts]);
    /*
        Any time the selected element changes we log the file
        ending (or none, if it has none).
    */
    useEffect(() => {
        let selectedElementName = '';
        if (selectedElement === undefined) {
            selectedElementName = 'undefined';
        }
        else if (selectedElement.isDirectory) {
            selectedElementName = 'directory';
        }
        else {
            const fileEnding = getFileEnding(selectedElement.name);
            if (fileEnding !== undefined) {
                selectedElementName = fileEnding;
            }
            else {
                selectedElementName = 'No File Ending';
            }
        }
        void props.mitoAPI.log('selected_element_changed', { 'selected_element': selectedElementName });
    }, [selectedElement]);
    // Loads the path data from the API and sets it for the file browser
    async function loadPathContents(currPathParts) {
        const _pathContents = await props.mitoAPI.getPathContents(currPathParts);
        if (_pathContents) {
            setImportState(prevImportState => {
                return Object.assign(Object.assign({}, prevImportState), { pathContents: _pathContents });
            });
        }
    }
    async function importElement(element) {
        const importButtonStatus = getImportButtonStatus(element, props.userProfile.excelImportEnabled, importState.loadingImport);
        // Quit early if the selected thing is not importable, or if there
        // is nothing even selected
        if (importButtonStatus.disabled || element === undefined) {
            return;
        }
        if (!(element === null || element === void 0 ? void 0 : element.isDirectory) && (element === null || element === void 0 ? void 0 : element.name.toLowerCase().endsWith('.xlsx'))) {
            setFileForImportWizard(element.name);
            return;
        }
        // Do the actual import
        const finalPath = [...props.currPathParts];
        finalPath.push(element.name);
        const joinedPath = await props.mitoAPI.getPathJoined(finalPath);
        if (joinedPath === undefined) {
            return;
        }
        // And then actually import it
        setImportState(prevImportState => {
            return Object.assign(Object.assign({}, prevImportState), { loadingImport: true });
        });
        await props.mitoAPI.editSimpleImport([joinedPath]);
        setImportState(prevImportState => {
            return Object.assign(Object.assign({}, prevImportState), { loadingImport: false });
        });
    }
    const importButtonStatus = getImportButtonStatus(selectedElement, props.userProfile.excelImportEnabled, importState.loadingImport);
    return (React.createElement(DefaultTaskpane, null,
        React.createElement(DefaultTaskpaneHeader, { header: fileForImportWizard === undefined ? 'Import Files' : `Import ${fileForImportWizard}`, setUIState: props.setUIState, backCallback: fileForImportWizard === undefined ? undefined : () => {
                setFileForImportWizard(undefined);
            } }),
        React.createElement(DefaultTaskpaneBody, { noScroll: true },
            React.createElement("div", { className: 'import-taskpane flexbox-column flexbox-space-between' },
                fileForImportWizard === undefined &&
                    React.createElement(React.Fragment, null,
                        React.createElement(FileBrowser, { mitoAPI: props.mitoAPI, setCurrPathParts: props.setCurrPathParts, importState: importState, setImportState: setImportState, importElement: importElement, userProfile: props.userProfile }),
                        React.createElement("div", { className: 'import-taskpane-import-button-container' },
                            React.createElement(TextButton, { variant: 'dark', width: 'block', onClick: () => {
                                    void importElement(selectedElement);
                                }, disabled: importButtonStatus.disabled }, importButtonStatus.buttonText))),
                fileForImportWizard !== undefined &&
                    React.createElement(XLSXImport, { mitoAPI: props.mitoAPI, pathParts: [...props.currPathParts, fileForImportWizard], importState: importState, setImportState: setImportState })))));
}
export default ImportTaskpane;
//# sourceMappingURL=ImportTaskpane.js.map

==> mitosheet2-0.1.40.tar.gz: package/lib/components/taskpanes/Import/ImportTaskpane.js <==
// Copyright (c) Mito
import React, { useEffect, useState } from 'react';
import DefaultTaskpane from '../DefaultTaskpane/DefaultTaskpane';
import FileBrowser from './FileBrowser';
import TextButton from '../../elements/TextButton';
import XLSXImport from './XLSXImport';
// CSS
import '../../../../css/taskpanes/Import/ImportTaskpane.css';
import DefaultTaskpaneHeader from '../DefaultTaskpane/DefaultTaskpaneHeader';
import DefaultTaskpaneBody from '../DefaultTaskpane/DefaultTaskpaneBody';
import { getElementsToDisplay, getFileEnding, getImportButtonStatus } from './importUtils';
function ImportTaskpane(props) {
    const [importState, setImportState] = useState({
        pathContents: {
            path_parts: props.currPathParts,
            elements: []
        },
        sort: 'last_modified_descending',
        searchString: '',
        selectedElementIndex: -1,
        loadingFolder: false,
        loadingImport: false
    });
    // If the file being imported is an XLSX, we need additional configuration
    // and so we use an import wizard for help
    const [fileForImportWizard, setFileForImportWizard] = useState(undefined);
    // We make sure to get the elements that are displayed and use the index on that to get the correct element
    const selectedElement = getElementsToDisplay(importState)[importState.selectedElementIndex];
    /*
        Any time the current path changes, we update
        the files that are displayed
    */
    useEffect(() => {
        // When the current path changes, we reload the path contents
        void loadPathContents(props.currPathParts);
        // We also unselect anything that might be selected
        setImportState(prevImportState => {
            return Object.assign(Object.assign({}, prevImportState), { selectedElementIndex: -1 });
        });
        // Log how long the path is
        void props.mitoAPI.log('curr_path_changed', { 'path_parts_length': props.currPathParts.length });
    }, [props.currPathParts]);
    /*
        Any time the selected element changes we log the file
        ending (or none, if it has none).
    */
    useEffect(() => {
        let selectedElementName = '';
        if (selectedElement === undefined) {
            selectedElementName = 'undefined';
        }
        else if (selectedElement.isDirectory) {
            selectedElementName = 'directory';
        }
        else {
            const fileEnding = getFileEnding(selectedElement.name);
            if (fileEnding !== undefined) {
                selectedElementName = fileEnding;
            }
            else {
                selectedElementName = 'No File Ending';
            }
        }
        void props.mitoAPI.log('selected_element_changed', { 'selected_element': selectedElementName });
    }, [selectedElement]);
    // Loads the path data from the API and sets it for the file browser
    async function loadPathContents(currPathParts) {
        setImportState(prevImportState => {
            return Object.assign(Object.assign({}, prevImportState), { loadingFolder: true });
        });
        const _pathContents = await props.mitoAPI.getPathContents(currPathParts);
        if (_pathContents) {
            setImportState(prevImportState => {
                return Object.assign(Object.assign({}, prevImportState), { pathContents: _pathContents, loadingFolder: false });
            });
        }
        else {
            setImportState(prevImportState => {
                return Object.assign(Object.assign({}, prevImportState), { loadingFolder: false });
            });
        }
    }
    async function importElement(element) {
        const importButtonStatus = getImportButtonStatus(element, props.userProfile.excelImportEnabled, importState.loadingImport);
        // Quit early if the selected thing is not importable, or if there
        // is nothing even selected
        if (importButtonStatus.disabled || element === undefined) {
            return;
        }
        if (!(element === null || element === void 0 ? void 0 : element.isDirectory) && (element === null || element === void 0 ? void 0 : element.name.toLowerCase().endsWith('.xlsx'))) {
            setFileForImportWizard(element.name);
            return;
        }
        // Do the actual import
        const finalPath = [...props.currPathParts];
        finalPath.push(element.name);
        const joinedPath = await props.mitoAPI.getPathJoined(finalPath);
        if (joinedPath === undefined) {
            return;
        }
        // And then actually import it
        setImportState(prevImportState => {
            return Object.assign(Object.assign({}, prevImportState), { loadingImport: true });
        });
        await props.mitoAPI.editSimpleImport([joinedPath]);
        setImportState(prevImportState => {
            return Object.assign(Object.assign({}, prevImportState), { loadingImport: false });
        });
    }
    const importButtonStatus = getImportButtonStatus(selectedElement, props.userProfile.excelImportEnabled, importState.loadingImport);
    return (React.createElement(DefaultTaskpane, null,
        React.createElement(DefaultTaskpaneHeader, { header: fileForImportWizard === undefined ? 'Import Files' : `Import ${fileForImportWizard}`, setUIState: props.setUIState, backCallback: fileForImportWizard === undefined ? undefined : () => {
                setFileForImportWizard(undefined);
            } }),
        React.createElement(DefaultTaskpaneBody, { noScroll: true },
            React.createElement("div", { className: 'import-taskpane flexbox-column flexbox-space-between' },
                fileForImportWizard === undefined &&
                    React.createElement(React.Fragment, null,
                        React.createElement(FileBrowser, { mitoAPI: props.mitoAPI, setCurrPathParts: props.setCurrPathParts, importState: importState, setImportState: setImportState, importElement: importElement, userProfile: props.userProfile }),
                        React.createElement("div", { className: 'import-taskpane-import-button-container' },
                            React.createElement(TextButton, { variant: 'dark', width: 'block', onClick: () => {
                                    void importElement(selectedElement);
                                }, disabled: importButtonStatus.disabled }, importButtonStatus.buttonText))),
                fileForImportWizard !== undefined &&
                    React.createElement(XLSXImport, { mitoAPI: props.mitoAPI, pathParts: [...props.currPathParts, fileForImportWizard], importState: importState, setImportState: setImportState })))));
}
export default ImportTaskpane;
//# sourceMappingURL=ImportTaskpane.js.map
